"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FrameworkOptions = exports.init = void 0;
const path_1 = __importDefault(require("path"));
const utils_1 = require("../utils");
const configuration_1 = __importDefault(require("../configuration"));
const create_configuration_1 = require("./create-configuration");
const spinner_1 = __importDefault(require("../outputs/spinner"));
async function init(name, protocol, projectPath, framework, silient) {
    const spinner = new spinner_1.default();
    try {
        spinner.spin(`Spheron initialization...`);
        if (await (0, utils_1.fileExists)("./spheron.json")) {
            throw new Error("Spheron file already exists");
        }
        if (!(await (0, utils_1.fileExists)(configuration_1.default.configFilePath)) ||
            !(await (0, utils_1.fileExists)(configuration_1.default.projectTrackingFilePath))) {
            await (0, create_configuration_1.createConfiguration)();
        }
        const pathSegments = process.cwd().split("/");
        const frameworkConfig = mapFrameworkConfig(framework);
        const spheronConfiguration = {
            name: name ? name : pathSegments[pathSegments.length - 1],
            protocol: protocol,
            rootPath: projectPath ? projectPath : "./",
            framework: {
                name: framework,
                configuration: frameworkConfig,
            },
        };
        await (0, utils_1.writeToJsonFile)("configuration", spheronConfiguration, path_1.default.join(process.cwd(), "./spheron.json"));
        const projects = await (0, utils_1.readFromJsonFile)("projects", configuration_1.default.projectTrackingFilePath);
        projects.push({
            name: name ? name : pathSegments[pathSegments.length - 1],
            path: projectPath
                ? path_1.default.join(process.cwd(), projectPath)
                : path_1.default.join(process.cwd(), "./"),
            protocol: protocol,
            framework: {
                name: framework,
                configuration: frameworkConfig,
            },
        });
        await (0, utils_1.writeToJsonFile)("projects", projects, configuration_1.default.projectTrackingFilePath);
        if (!silient) {
            spinner.success("Spheron initialized");
        }
    }
    catch (error) {
        console.log(`✖️  Error: ${error.message}`);
    }
    finally {
        spinner.stop();
    }
}
exports.init = init;
function mapFrameworkConfig(framework) {
    switch (framework) {
        case FrameworkOptions.Static:
            return {
                installCommand: "",
                buildCommand: "",
                publishDirectory: "",
            };
        case FrameworkOptions.React:
        case FrameworkOptions.IonicReact:
        case FrameworkOptions.Preact:
        case FrameworkOptions.Docusaurus:
            return {
                installCommand: "yarn install",
                buildCommand: "yarn build",
                publishDirectory: "build",
            };
        case FrameworkOptions.Vue:
        case FrameworkOptions.Sanity:
        case FrameworkOptions.Vite:
        case FrameworkOptions.Scully:
            return {
                installCommand: "yarn install",
                buildCommand: "yarn build",
                publishDirectory: "dist",
            };
        case FrameworkOptions.Angular:
        case FrameworkOptions.IonicAngular:
            return {
                installCommand: "yarn install",
                buildCommand: "yarn build",
                publishDirectory: "dist/app",
            };
        case FrameworkOptions.Next:
            return {
                installCommand: "yarn install",
                buildCommand: "next build && next export",
                publishDirectory: "out",
            };
        case FrameworkOptions.Nuxt2:
            return {
                installCommand: "yarn install",
                buildCommand: "yarn generate",
                publishDirectory: "dist",
            };
        case FrameworkOptions.Hugo:
            return {
                installCommand: "",
                buildCommand: "hugo -D --gc",
                publishDirectory: "public",
            };
        case FrameworkOptions.Eleventy:
            return {
                installCommand: "yarn install",
                buildCommand: "yarn build",
                publishDirectory: "_site",
            };
        case FrameworkOptions.Svelte:
        case FrameworkOptions.Gatsby:
            return {
                installCommand: "yarn install",
                buildCommand: "yarn build",
                publishDirectory: "public",
            };
        case FrameworkOptions.Stencil:
            return {
                installCommand: "yarn install",
                buildCommand: "yarn build",
                publishDirectory: "www",
            };
        case FrameworkOptions.Brunch:
            return {
                installCommand: "yarn install",
                buildCommand: "yarn build",
                publishDirectory: "public",
            };
        default:
            return {
                installCommand: "",
                buildCommand: "",
                publishDirectory: "",
            };
    }
}
var FrameworkOptions;
(function (FrameworkOptions) {
    FrameworkOptions["Static"] = "static";
    FrameworkOptions["React"] = "react";
    FrameworkOptions["Vue"] = "vue";
    FrameworkOptions["Angular"] = "angular";
    FrameworkOptions["Next"] = "next";
    FrameworkOptions["Preact"] = "preact";
    FrameworkOptions["Nuxt2"] = "nuxt2";
    FrameworkOptions["Docusaurus"] = "docusaurus";
    FrameworkOptions["Hugo"] = "hugo";
    FrameworkOptions["Eleventy"] = "eleventy";
    FrameworkOptions["Svelte"] = "svelte";
    FrameworkOptions["Gatsby"] = "gatsby";
    FrameworkOptions["Sanity"] = "sanity";
    FrameworkOptions["IonicReact"] = "ionicreact";
    FrameworkOptions["Vite"] = "vite";
    FrameworkOptions["Scully"] = "scully";
    FrameworkOptions["Stencil"] = "stencil";
    FrameworkOptions["Brunch"] = "brunch";
    FrameworkOptions["IonicAngular"] = "ionicangular";
})(FrameworkOptions = exports.FrameworkOptions || (exports.FrameworkOptions = {}));
